@@ -23,27 +23,18 @@
 
 #ifndef _GAUSSSEIDELHANDLE_HPP
 #define _GAUSSSEIDELHANDLE_HPP
-//#define VERBOSE
+// #define VERBOSE
 
 namespace KokkosSparse {
 
 enum GSAlgorithm { GS_DEFAULT, GS_PERMUTED, GS_TEAM, GS_CLUSTER, GS_TWOSTAGE };
 enum GSDirection { GS_FORWARD, GS_BACKWARD, GS_SYMMETRIC };
-enum struct ClusteringAlgorithm {
-  CLUSTER_DEFAULT,
-  CLUSTER_MIS2,
-  CLUSTER_BALLOON,
-  NUM_CLUSTERING_ALGORITHMS
-};
+enum struct ClusteringAlgorithm { CLUSTER_DEFAULT, CLUSTER_MIS2, CLUSTER_BALLOON, NUM_CLUSTERING_ALGORITHMS };
 
-static constexpr ClusteringAlgorithm CLUSTER_DEFAULT =
-    ClusteringAlgorithm::CLUSTER_DEFAULT;
-static constexpr ClusteringAlgorithm CLUSTER_MIS2 =
-    ClusteringAlgorithm::CLUSTER_MIS2;
-static constexpr ClusteringAlgorithm CLUSTER_BALLOON =
-    ClusteringAlgorithm::CLUSTER_BALLOON;
-static constexpr ClusteringAlgorithm NUM_CLUSTERING_ALGORITHMS =
-    ClusteringAlgorithm::NUM_CLUSTERING_ALGORITHMS;
+static constexpr ClusteringAlgorithm CLUSTER_DEFAULT           = ClusteringAlgorithm::CLUSTER_DEFAULT;
+static constexpr ClusteringAlgorithm CLUSTER_MIS2              = ClusteringAlgorithm::CLUSTER_MIS2;
+static constexpr ClusteringAlgorithm CLUSTER_BALLOON           = ClusteringAlgorithm::CLUSTER_BALLOON;
+static constexpr ClusteringAlgorithm NUM_CLUSTERING_ALGORITHMS = ClusteringAlgorithm::NUM_CLUSTERING_ALGORITHMS;
 
 inline const char *getClusterAlgoName(ClusteringAlgorithm ca) {
   switch (ca) {
@@ -54,8 +45,8 @@ inline const char *getClusterAlgoName(ClusteringAlgorithm ca) {
   return "INVALID CLUSTERING ALGORITHM";
 }
 
-template <class size_type_, class lno_t_, class scalar_t_, class ExecutionSpace,
-          class TemporaryMemorySpace, class PersistentMemorySpace>
+template <class size_type_, class lno_t_, class scalar_t_, class ExecutionSpace, class TemporaryMemorySpace,
+          class PersistentMemorySpace>
 class GaussSeidelHandle {
  public:
   typedef ExecutionSpace HandleExecSpace;
@@ -71,26 +62,17 @@ class GaussSeidelHandle {
   typedef typename std::remove_const<scalar_t_>::type nnz_scalar_t;
   typedef const nnz_scalar_t const_nnz_scalar_t;
 
-  typedef typename Kokkos::View<size_type *, HandleTempMemorySpace>
-      row_lno_temp_work_view_t;
-  typedef typename Kokkos::View<size_type *, HandlePersistentMemorySpace>
-      row_lno_persistent_work_view_t;
-  typedef typename row_lno_persistent_work_view_t::HostMirror
-      row_lno_persistent_work_host_view_t;  // Host view type
+  typedef typename Kokkos::View<size_type *, HandleTempMemorySpace> row_lno_temp_work_view_t;
+  typedef typename Kokkos::View<size_type *, HandlePersistentMemorySpace> row_lno_persistent_work_view_t;
+  typedef typename row_lno_persistent_work_view_t::HostMirror row_lno_persistent_work_host_view_t;  // Host view type
 
-  typedef typename Kokkos::View<nnz_scalar_t *, HandleTempMemorySpace>
-      scalar_temp_work_view_t;
-  typedef typename Kokkos::View<nnz_scalar_t *, HandlePersistentMemorySpace>
-      scalar_persistent_work_view_t;
-  typedef typename scalar_persistent_work_view_t::HostMirror
-      scalar_persistent_work_host_view_t;  // Host view type
+  typedef typename Kokkos::View<nnz_scalar_t *, HandleTempMemorySpace> scalar_temp_work_view_t;
+  typedef typename Kokkos::View<nnz_scalar_t *, HandlePersistentMemorySpace> scalar_persistent_work_view_t;
+  typedef typename scalar_persistent_work_view_t::HostMirror scalar_persistent_work_host_view_t;  // Host view type
 
-  typedef typename Kokkos::View<nnz_lno_t *, HandleTempMemorySpace>
-      nnz_lno_temp_work_view_t;
-  typedef typename Kokkos::View<nnz_lno_t *, HandlePersistentMemorySpace>
-      nnz_lno_persistent_work_view_t;
-  typedef typename nnz_lno_persistent_work_view_t::HostMirror
-      nnz_lno_persistent_work_host_view_t;  // Host view type
+  typedef typename Kokkos::View<nnz_lno_t *, HandleTempMemorySpace> nnz_lno_temp_work_view_t;
+  typedef typename Kokkos::View<nnz_lno_t *, HandlePersistentMemorySpace> nnz_lno_persistent_work_view_t;
+  typedef typename nnz_lno_persistent_work_view_t::HostMirror nnz_lno_persistent_work_host_view_t;  // Host view type
 
  protected:
   HandleExecSpace execution_space;
@@ -124,8 +106,7 @@ class GaussSeidelHandle {
         suggested_vector_size(0),
         suggested_team_size(0) {}
 
-  GaussSeidelHandle(HandleExecSpace handle_exec_space, int n_streams,
-                    GSAlgorithm gs)
+  GaussSeidelHandle(HandleExecSpace handle_exec_space, int n_streams, GSAlgorithm gs)
       : execution_space(handle_exec_space),
         num_streams(n_streams),
         algorithm_type(gs),
@@ -146,12 +127,8 @@ class GaussSeidelHandle {
 
   GSAlgorithm get_algorithm_type() const { return this->algorithm_type; }
 
-  nnz_lno_persistent_work_host_view_t get_color_xadj() const {
-    return this->color_xadj;
-  }
-  nnz_lno_persistent_work_view_t get_color_adj() const {
-    return this->color_adj;
-  }
+  nnz_lno_persistent_work_host_view_t get_color_xadj() const { return this->color_xadj; }
+  nnz_lno_persistent_work_view_t get_color_adj() const { return this->color_adj; }
   nnz_lno_t get_num_colors() const { return this->numColors; }
 
   bool is_symbolic_called() const { return this->called_symbolic; }
@@ -183,15 +160,9 @@ class GaussSeidelHandle {
   void set_call_symbolic(bool call = true) { this->called_symbolic = call; }
   void set_call_numeric(bool call = true) { this->called_numeric = call; }
 
-  void set_color_xadj(const nnz_lno_persistent_work_host_view_t &color_xadj_) {
-    this->color_xadj = color_xadj_;
-  }
-  void set_color_adj(const nnz_lno_persistent_work_view_t &color_adj_) {
-    this->color_adj = color_adj_;
-  }
-  void set_num_colors(const nnz_lno_t &numColors_) {
-    this->numColors = numColors_;
-  }
+  void set_color_xadj(const nnz_lno_persistent_work_host_view_t &color_xadj_) { this->color_xadj = color_xadj_; }
+  void set_color_adj(const nnz_lno_persistent_work_view_t &color_adj_) { this->color_adj = color_adj_; }
+  void set_num_colors(const nnz_lno_t &numColors_) { this->numColors = numColors_; }
 
   void vector_team_size(int max_allowed_team_size,
                         int &suggested_vector_size_,  // output
@@ -202,24 +173,21 @@ class GaussSeidelHandle {
       suggested_team_size_   = this->suggested_team_size;
       return;
     } else {
-      KokkosKernels::Impl::get_suggested_vector_size<size_type, ExecutionSpace>(
-          suggested_vector_size_, nr, nnz);
-      KokkosKernels::Impl::get_suggested_team_size<ExecutionSpace>(
-          max_allowed_team_size, suggested_vector_size_, suggested_team_size_);
+      KokkosKernels::Impl::get_suggested_vector_size<size_type, ExecutionSpace>(suggested_vector_size_, nr, nnz);
+      KokkosKernels::Impl::get_suggested_team_size<ExecutionSpace>(max_allowed_team_size, suggested_vector_size_,
+                                                                   suggested_team_size_);
       this->suggested_team_size   = suggested_vector_size_;
       this->suggested_vector_size = suggested_vector_size_;
     }
   }
 };
 
-template <class size_type_, class lno_t_, class scalar_t_, class ExecutionSpace,
-          class TemporaryMemorySpace, class PersistentMemorySpace>
-class PointGaussSeidelHandle
-    : public GaussSeidelHandle<size_type_, lno_t_, scalar_t_, ExecutionSpace,
-                               TemporaryMemorySpace, PersistentMemorySpace> {
+template <class size_type_, class lno_t_, class scalar_t_, class ExecutionSpace, class TemporaryMemorySpace,
+          class PersistentMemorySpace>
+class PointGaussSeidelHandle : public GaussSeidelHandle<size_type_, lno_t_, scalar_t_, ExecutionSpace,
+                                                        TemporaryMemorySpace, PersistentMemorySpace> {
  public:
-  typedef GaussSeidelHandle<size_type_, lno_t_, scalar_t_, ExecutionSpace,
-                            TemporaryMemorySpace, PersistentMemorySpace>
+  typedef GaussSeidelHandle<size_type_, lno_t_, scalar_t_, ExecutionSpace, TemporaryMemorySpace, PersistentMemorySpace>
       GSHandle;
   typedef ExecutionSpace HandleExecSpace;
   typedef TemporaryMemorySpace HandleTempMemorySpace;
@@ -234,29 +202,19 @@ class PointGaussSeidelHandle
   typedef typename std::remove_const<scalar_t_>::type nnz_scalar_t;
   typedef const nnz_scalar_t const_nnz_scalar_t;
 
-  typedef typename Kokkos::View<size_type *, HandleTempMemorySpace>
-      row_lno_temp_work_view_t;
-  typedef typename Kokkos::View<size_type *, HandlePersistentMemorySpace>
-      row_lno_persistent_work_view_t;
-  typedef typename row_lno_persistent_work_view_t::HostMirror
-      row_lno_persistent_work_host_view_t;  // Host view type
+  typedef typename Kokkos::View<size_type *, HandleTempMemorySpace> row_lno_temp_work_view_t;
+  typedef typename Kokkos::View<size_type *, HandlePersistentMemorySpace> row_lno_persistent_work_view_t;
+  typedef typename row_lno_persistent_work_view_t::HostMirror row_lno_persistent_work_host_view_t;  // Host view type
 
-  typedef typename Kokkos::View<nnz_scalar_t *, HandleTempMemorySpace>
-      scalar_temp_work_view_t;
-  typedef typename Kokkos::View<nnz_scalar_t *, HandlePersistentMemorySpace>
-      scalar_persistent_work_view_t;
-  typedef typename Kokkos::View<nnz_scalar_t **, default_layout,
-                                HandlePersistentMemorySpace>
+  typedef typename Kokkos::View<nnz_scalar_t *, HandleTempMemorySpace> scalar_temp_work_view_t;
+  typedef typename Kokkos::View<nnz_scalar_t *, HandlePersistentMemorySpace> scalar_persistent_work_view_t;
+  typedef typename Kokkos::View<nnz_scalar_t **, KokkosKernels::default_layout, HandlePersistentMemorySpace>
       scalar_persistent_work_view2d_t;
-  typedef typename scalar_persistent_work_view_t::HostMirror
-      scalar_persistent_work_host_view_t;  // Host view type
+  typedef typename scalar_persistent_work_view_t::HostMirror scalar_persistent_work_host_view_t;  // Host view type
 
-  typedef typename Kokkos::View<nnz_lno_t *, HandleTempMemorySpace>
-      nnz_lno_temp_work_view_t;
-  typedef typename Kokkos::View<nnz_lno_t *, HandlePersistentMemorySpace>
-      nnz_lno_persistent_work_view_t;
-  typedef typename nnz_lno_persistent_work_view_t::HostMirror
-      nnz_lno_persistent_work_host_view_t;  // Host view type
+  typedef typename Kokkos::View<nnz_lno_t *, HandleTempMemorySpace> nnz_lno_temp_work_view_t;
+  typedef typename Kokkos::View<nnz_lno_t *, HandlePersistentMemorySpace> nnz_lno_persistent_work_view_t;
+  typedef typename nnz_lno_persistent_work_view_t::HostMirror nnz_lno_persistent_work_host_view_t;  // Host view type
 
  private:
   row_lno_persistent_work_view_t permuted_xadj;
@@ -293,8 +251,7 @@ class PointGaussSeidelHandle
    * \brief Default constructor.
    */
   PointGaussSeidelHandle(GSHandle gs_handle,
-                         KokkosGraph::ColoringAlgorithm coloring_algo_ =
-                             KokkosGraph::COLORING_DEFAULT)
+                         KokkosGraph::ColoringAlgorithm coloring_algo_ = KokkosGraph::COLORING_DEFAULT)
       : GSHandle(gs_handle),
         permuted_xadj(),
         permuted_adj(),
@@ -311,102 +268,63 @@ class PointGaussSeidelHandle
         level_2_mem(0),
         long_row_threshold(0),
         coloring_algo(coloring_algo_) {
-    if (gs_handle.get_algorithm_type() == GS_DEFAULT)
-      this->choose_default_algorithm();
+    if (gs_handle.get_algorithm_type() == GS_DEFAULT) this->choose_default_algorithm();
   }
 
-  PointGaussSeidelHandle(GSAlgorithm gs = GS_DEFAULT,
-                         KokkosGraph::ColoringAlgorithm coloring_algo_ =
-                             KokkosGraph::COLORING_DEFAULT)
+  PointGaussSeidelHandle(GSAlgorithm gs                                = GS_DEFAULT,
+                         KokkosGraph::ColoringAlgorithm coloring_algo_ = KokkosGraph::COLORING_DEFAULT)
       : PointGaussSeidelHandle(GSHandle(gs), coloring_algo_) {}
 
-  PointGaussSeidelHandle(HandleExecSpace handle_exec_space, int n_streams,
-                         GSAlgorithm gs = GS_DEFAULT,
-                         KokkosGraph::ColoringAlgorithm coloring_algo_ =
-                             KokkosGraph::COLORING_DEFAULT)
-      : PointGaussSeidelHandle(GSHandle(handle_exec_space, n_streams, gs),
-                               coloring_algo_) {}
+  PointGaussSeidelHandle(HandleExecSpace handle_exec_space, int n_streams, GSAlgorithm gs = GS_DEFAULT,
+                         KokkosGraph::ColoringAlgorithm coloring_algo_ = KokkosGraph::COLORING_DEFAULT)
+      : PointGaussSeidelHandle(GSHandle(handle_exec_space, n_streams, gs), coloring_algo_) {}
 
   void set_block_size(nnz_lno_t bs) { this->block_size = bs; }
   nnz_lno_t get_block_size() const { return this->block_size; }
 
   void choose_default_algorithm() {
-    if (KokkosKernels::Impl::kk_is_gpu_exec_space<ExecutionSpace>())
+    if (KokkosKernels::Impl::is_gpu_exec_space_v<ExecutionSpace>)
       this->algorithm_type = GS_TEAM;
     else
       this->algorithm_type = GS_PERMUTED;
   }
 
-  KokkosGraph::ColoringAlgorithm get_coloring_algorithm() const {
-    return this->coloring_algo;
-  }
-  void set_coloring_algorithm(KokkosGraph::ColoringAlgorithm algo) {
-    this->coloring_algo = algo;
-  }
+  KokkosGraph::ColoringAlgorithm get_coloring_algorithm() const { return this->coloring_algo; }
+  void set_coloring_algorithm(KokkosGraph::ColoringAlgorithm algo) { this->coloring_algo = algo; }
 
   ~PointGaussSeidelHandle() = default;
 
   // getters
-  row_lno_persistent_work_view_t get_new_xadj() const {
-    return this->permuted_xadj;
-  }
-  nnz_lno_persistent_work_view_t get_new_adj() const {
-    return this->permuted_adj;
-  }
-  scalar_persistent_work_view_t get_new_adj_val() const {
-    return this->permuted_adj_vals;
-  }
-  nnz_lno_persistent_work_view_t get_old_to_new_map() const {
-    return this->old_to_new_map;
-  }
+  row_lno_persistent_work_view_t get_new_xadj() const { return this->permuted_xadj; }
+  nnz_lno_persistent_work_view_t get_new_adj() const { return this->permuted_adj; }
+  scalar_persistent_work_view_t get_new_adj_val() const { return this->permuted_adj_vals; }
+  nnz_lno_persistent_work_view_t get_old_to_new_map() const { return this->old_to_new_map; }
 
   // setters
-  void set_algorithm_type(const GSAlgorithm &sgs_algo) {
-    this->algorithm_type = sgs_algo;
-  }
+  void set_algorithm_type(const GSAlgorithm &sgs_algo) { this->algorithm_type = sgs_algo; }
 
   void set_call_symbolic(bool call = true) { this->called_symbolic = call; }
   void set_call_numeric(bool call = true) { this->called_numeric = call; }
 
-  void set_num_colors(const nnz_lno_t &numColors_) {
-    this->numColors = numColors_;
-  }
+  void set_num_colors(const nnz_lno_t &numColors_) { this->numColors = numColors_; }
 
-  void set_new_xadj(const row_lno_persistent_work_view_t &xadj_) {
-    this->permuted_xadj = xadj_;
-  }
-  void set_new_adj(const nnz_lno_persistent_work_view_t &adj_) {
-    this->permuted_adj = adj_;
-  }
-  void set_new_adj_val(const scalar_persistent_work_view_t &adj_vals_) {
-    this->permuted_adj_vals = adj_vals_;
-  }
-  void set_old_to_new_map(
-      const nnz_lno_persistent_work_view_t &old_to_new_map_) {
+  void set_new_xadj(const row_lno_persistent_work_view_t &xadj_) { this->permuted_xadj = xadj_; }
+  void set_new_adj(const nnz_lno_persistent_work_view_t &adj_) { this->permuted_adj = adj_; }
+  void set_new_adj_val(const scalar_persistent_work_view_t &adj_vals_) { this->permuted_adj_vals = adj_vals_; }
+  void set_old_to_new_map(const nnz_lno_persistent_work_view_t &old_to_new_map_) {
     this->old_to_new_map = old_to_new_map_;
   }
-  void set_permuted_inverse_diagonal(
-      const scalar_persistent_work_view_t permuted_inverse_diagonal_) {
+  void set_permuted_inverse_diagonal(const scalar_persistent_work_view_t permuted_inverse_diagonal_) {
     this->permuted_inverse_diagonal = permuted_inverse_diagonal_;
   }
 
-  scalar_persistent_work_view_t get_permuted_inverse_diagonal() const {
-    return this->permuted_inverse_diagonal;
-  }
+  scalar_persistent_work_view_t get_permuted_inverse_diagonal() const { return this->permuted_inverse_diagonal; }
 
-  void set_level_1_mem(size_t _level_1_mem) {
-    this->level_1_mem = _level_1_mem;
-  }
-  void set_level_2_mem(size_t _level_2_mem) {
-    this->level_2_mem = _level_2_mem;
-  }
+  void set_level_1_mem(size_t _level_1_mem) { this->level_1_mem = _level_1_mem; }
+  void set_level_2_mem(size_t _level_2_mem) { this->level_2_mem = _level_2_mem; }
 
-  void set_num_values_in_l1(nnz_lno_t _num_values_in_l1) {
-    this->num_values_in_l1 = _num_values_in_l1;
-  }
-  void set_num_values_in_l2(nnz_lno_t _num_values_in_l2) {
-    this->num_values_in_l2 = _num_values_in_l2;
-  }
+  void set_num_values_in_l1(nnz_lno_t _num_values_in_l1) { this->num_values_in_l1 = _num_values_in_l1; }
+  void set_num_values_in_l2(nnz_lno_t _num_values_in_l2) { this->num_values_in_l2 = _num_values_in_l2; }
 
   void set_num_big_rows(nnz_lno_t _big_rows) { this->num_big_rows = _big_rows; }
 
@@ -421,53 +339,35 @@ class PointGaussSeidelHandle
 
   void set_long_row_threshold(nnz_lno_t lrt) { long_row_threshold = lrt; }
 
-  nnz_lno_persistent_work_host_view_t get_long_rows_per_color() const {
-    return long_rows_per_color;
-  }
+  nnz_lno_persistent_work_host_view_t get_long_rows_per_color() const { return long_rows_per_color; }
 
-  void set_long_rows_per_color(
-      const nnz_lno_persistent_work_host_view_t &long_rows_per_color_) {
+  void set_long_rows_per_color(const nnz_lno_persistent_work_host_view_t &long_rows_per_color_) {
     long_rows_per_color = long_rows_per_color_;
   }
 
-  nnz_lno_persistent_work_host_view_t get_max_row_length_per_color() const {
-    return max_row_length_per_color;
-  }
+  nnz_lno_persistent_work_host_view_t get_max_row_length_per_color() const { return max_row_length_per_color; }
 
-  void set_max_row_length_per_color(
-      const nnz_lno_persistent_work_host_view_t &max_row_length_per_color_) {
+  void set_max_row_length_per_color(const nnz_lno_persistent_work_host_view_t &max_row_length_per_color_) {
     max_row_length_per_color = max_row_length_per_color_;
   }
 
   scalar_persistent_work_view_t get_long_row_x() const { return long_row_x; }
 
-  void set_long_row_x(const scalar_persistent_work_view_t &long_row_x_) {
-    long_row_x = long_row_x_;
-  }
+  void set_long_row_x(const scalar_persistent_work_view_t &long_row_x_) { long_row_x = long_row_x_; }
 
-  void allocate_x_y_vectors(nnz_lno_t num_rows, nnz_lno_t num_cols,
-                            nnz_lno_t num_vecs) {
-    if (permuted_y_vector.extent(0) != size_t(num_rows) ||
-        permuted_y_vector.extent(1) != size_t(num_vecs)) {
-      permuted_y_vector = scalar_persistent_work_view2d_t("PERMUTED Y VECTOR",
-                                                          num_rows, num_vecs);
+  void allocate_x_y_vectors(nnz_lno_t num_rows, nnz_lno_t num_cols, nnz_lno_t num_vecs) {
+    if (permuted_y_vector.extent(0) != size_t(num_rows) || permuted_y_vector.extent(1) != size_t(num_vecs)) {
+      permuted_y_vector = scalar_persistent_work_view2d_t("PERMUTED Y VECTOR", num_rows, num_vecs);
     }
-    if (permuted_x_vector.extent(0) != size_t(num_cols) ||
-        permuted_x_vector.extent(1) != size_t(num_vecs)) {
-      permuted_x_vector = scalar_persistent_work_view2d_t("PERMUTED X VECTOR",
-                                                          num_cols, num_vecs);
+    if (permuted_x_vector.extent(0) != size_t(num_cols) || permuted_x_vector.extent(1) != size_t(num_vecs)) {
+      permuted_x_vector = scalar_persistent_work_view2d_t("PERMUTED X VECTOR", num_cols, num_vecs);
     }
   }
 
-  scalar_persistent_work_view2d_t get_permuted_y_vector() const {
-    return this->permuted_y_vector;
-  }
-  scalar_persistent_work_view2d_t get_permuted_x_vector() const {
-    return this->permuted_x_vector;
-  }
+  scalar_persistent_work_view2d_t get_permuted_y_vector() const { return this->permuted_y_vector; }
+  scalar_persistent_work_view2d_t get_permuted_x_vector() const { return this->permuted_x_vector; }
 
-  void vector_team_size(int max_allowed_team_size, int &suggested_vector_size_,
-                        int &suggested_team_size_, size_type nr,
+  void vector_team_size(int max_allowed_team_size, int &suggested_vector_size_, int &suggested_team_size_, size_type nr,
                         size_type nnz) {
     // suggested_team_size_ =  this->suggested_team_size = 1;
     // suggested_vector_size_=this->suggested_vector_size = 1;
@@ -477,24 +377,21 @@ class PointGaussSeidelHandle
       suggested_team_size_   = this->suggested_team_size;
       return;
     } else {
-      KokkosKernels::Impl::get_suggested_vector_size<size_type, ExecutionSpace>(
-          suggested_vector_size_, nr, nnz);
-      KokkosKernels::Impl::get_suggested_team_size<ExecutionSpace>(
-          max_allowed_team_size, suggested_vector_size_, suggested_team_size_);
+      KokkosKernels::Impl::get_suggested_vector_size<size_type, ExecutionSpace>(suggested_vector_size_, nr, nnz);
+      KokkosKernels::Impl::get_suggested_team_size<ExecutionSpace>(max_allowed_team_size, suggested_vector_size_,
+                                                                   suggested_team_size_);
       this->suggested_team_size   = suggested_vector_size_;
       this->suggested_vector_size = suggested_vector_size_;
     }
   }
 };
 
-template <class size_type_, class lno_t_, class scalar_t_, class ExecutionSpace,
-          class TemporaryMemorySpace, class PersistentMemorySpace>
-class ClusterGaussSeidelHandle
-    : public GaussSeidelHandle<size_type_, lno_t_, scalar_t_, ExecutionSpace,
-                               TemporaryMemorySpace, PersistentMemorySpace> {
+template <class size_type_, class lno_t_, class scalar_t_, class ExecutionSpace, class TemporaryMemorySpace,
+          class PersistentMemorySpace>
+class ClusterGaussSeidelHandle : public GaussSeidelHandle<size_type_, lno_t_, scalar_t_, ExecutionSpace,
+                                                          TemporaryMemorySpace, PersistentMemorySpace> {
  public:
-  typedef GaussSeidelHandle<size_type_, lno_t_, scalar_t_, ExecutionSpace,
-                            TemporaryMemorySpace, PersistentMemorySpace>
+  typedef GaussSeidelHandle<size_type_, lno_t_, scalar_t_, ExecutionSpace, TemporaryMemorySpace, PersistentMemorySpace>
       GSHandle;
   typedef ExecutionSpace HandleExecSpace;
   typedef TemporaryMemorySpace HandleTempMemorySpace;
@@ -509,26 +406,17 @@ class ClusterGaussSeidelHandle
   typedef typename std::remove_const<scalar_t_>::type nnz_scalar_t;
   typedef const nnz_scalar_t const_nnz_scalar_t;
 
-  typedef typename Kokkos::View<size_type *, HandleTempMemorySpace>
-      row_lno_temp_work_view_t;
-  typedef typename Kokkos::View<size_type *, HandlePersistentMemorySpace>
-      row_lno_persistent_work_view_t;
-  typedef typename row_lno_persistent_work_view_t::HostMirror
-      row_lno_persistent_work_host_view_t;  // Host view type
+  typedef typename Kokkos::View<size_type *, HandleTempMemorySpace> row_lno_temp_work_view_t;
+  typedef typename Kokkos::View<size_type *, HandlePersistentMemorySpace> row_lno_persistent_work_view_t;
+  typedef typename row_lno_persistent_work_view_t::HostMirror row_lno_persistent_work_host_view_t;  // Host view type
 
-  typedef typename Kokkos::View<nnz_scalar_t *, HandleTempMemorySpace>
-      scalar_temp_work_view_t;
-  typedef typename Kokkos::View<nnz_scalar_t *, HandlePersistentMemorySpace>
-      scalar_persistent_work_view_t;
-  typedef typename scalar_persistent_work_view_t::HostMirror
-      scalar_persistent_work_host_view_t;  // Host view type
+  typedef typename Kokkos::View<nnz_scalar_t *, HandleTempMemorySpace> scalar_temp_work_view_t;
+  typedef typename Kokkos::View<nnz_scalar_t *, HandlePersistentMemorySpace> scalar_persistent_work_view_t;
+  typedef typename scalar_persistent_work_view_t::HostMirror scalar_persistent_work_host_view_t;  // Host view type
 
-  typedef typename Kokkos::View<nnz_lno_t *, HandleTempMemorySpace>
-      nnz_lno_temp_work_view_t;
-  typedef typename Kokkos::View<nnz_lno_t *, HandlePersistentMemorySpace>
-      nnz_lno_persistent_work_view_t;
-  typedef typename nnz_lno_persistent_work_view_t::HostMirror
-      nnz_lno_persistent_work_host_view_t;  // Host view type
+  typedef typename Kokkos::View<nnz_lno_t *, HandleTempMemorySpace> nnz_lno_temp_work_view_t;
+  typedef typename Kokkos::View<nnz_lno_t *, HandlePersistentMemorySpace> nnz_lno_persistent_work_view_t;
+  typedef typename nnz_lno_persistent_work_view_t::HostMirror nnz_lno_persistent_work_host_view_t;  // Host view type
 
  private:
   ClusteringAlgorithm cluster_algo;
@@ -558,8 +446,7 @@ class ClusterGaussSeidelHandle
    */
 
   // Constructor for cluster-coloring based GS and SGS
-  ClusterGaussSeidelHandle(ClusteringAlgorithm cluster_algo_,
-                           nnz_lno_t cluster_size_,
+  ClusterGaussSeidelHandle(ClusteringAlgorithm cluster_algo_, nnz_lno_t cluster_size_,
                            KokkosGraph::ColoringAlgorithm coloring_algo_)
       : GSHandle(GS_CLUSTER),
         cluster_algo(cluster_algo_),
@@ -573,58 +460,39 @@ class ClusterGaussSeidelHandle
   void set_cluster_size(nnz_lno_t cs) { this->cluster_size = cs; }
   nnz_lno_t get_cluster_size() const { return this->cluster_size; }
 
-  KokkosGraph::ColoringAlgorithm get_coloring_algorithm() const {
-    return this->coloring_algo;
-  }
-  void set_coloring_algorithm(KokkosGraph::ColoringAlgorithm algo) {
-    this->coloring_algo = algo;
-  }
+  KokkosGraph::ColoringAlgorithm get_coloring_algorithm() const { return this->coloring_algo; }
+  void set_coloring_algorithm(KokkosGraph::ColoringAlgorithm algo) { this->coloring_algo = algo; }
 
-  void set_vert_clusters(nnz_lno_persistent_work_view_t &vert_clusters_) {
-    this->vert_clusters = vert_clusters_;
-  }
-  void set_cluster_xadj(nnz_lno_persistent_work_view_t &cluster_xadj_) {
-    this->cluster_xadj = cluster_xadj_;
-  }
-  void set_cluster_adj(nnz_lno_persistent_work_view_t &cluster_adj_) {
-    this->cluster_adj = cluster_adj_;
-  }
+  void set_vert_clusters(nnz_lno_persistent_work_view_t &vert_clusters_) { this->vert_clusters = vert_clusters_; }
+  void set_cluster_xadj(nnz_lno_persistent_work_view_t &cluster_xadj_) { this->cluster_xadj = cluster_xadj_; }
+  void set_cluster_adj(nnz_lno_persistent_work_view_t &cluster_adj_) { this->cluster_adj = cluster_adj_; }
 
   nnz_lno_persistent_work_view_t get_vert_clusters() const {
     if (!this->is_symbolic_called())
-      throw std::runtime_error(
-          "vert_clusters does not exist until after symbolic setup.");
+      throw std::runtime_error("vert_clusters does not exist until after symbolic setup.");
     return vert_clusters;
   }
 
   nnz_lno_persistent_work_view_t get_cluster_xadj() const {
     if (!this->is_symbolic_called())
-      throw std::runtime_error(
-          "cluster_xadj does not exist until after symbolic setup.");
+      throw std::runtime_error("cluster_xadj does not exist until after symbolic setup.");
     return cluster_xadj;
   }
 
   nnz_lno_persistent_work_view_t get_cluster_adj() const {
-    if (!this->is_symbolic_called())
-      throw std::runtime_error(
-          "cluster_adj does not exist until after symbolic setup.");
+    if (!this->is_symbolic_called()) throw std::runtime_error("cluster_adj does not exist until after symbolic setup.");
     return cluster_adj;
   }
 
-  void set_inverse_diagonal(scalar_persistent_work_view_t &inv_diag) {
-    this->inverse_diagonal = inv_diag;
-  }
+  void set_inverse_diagonal(scalar_persistent_work_view_t &inv_diag) { this->inverse_diagonal = inv_diag; }
 
   scalar_persistent_work_view_t get_inverse_diagonal() const {
     if (!this->is_symbolic_called())
-      throw std::runtime_error(
-          "inverse diagonal does not exist until after numeric setup.");
+      throw std::runtime_error("inverse diagonal does not exist until after numeric setup.");
     return inverse_diagonal;
   }
 
-  bool use_teams() const {
-    return KokkosKernels::Impl::kk_is_gpu_exec_space<ExecutionSpace>();
-  }
+  bool use_teams() const { return KokkosKernels::Impl::is_gpu_exec_space_v<ExecutionSpace>; }
 
   ~ClusterGaussSeidelHandle() = default;
 
@@ -633,12 +501,10 @@ class ClusterGaussSeidelHandle
 
 // -------------------------------------
 // Handle for Two-stage/Classical GS
-template <typename input_size_t, typename input_ordinal_t,
-          typename input_scalar_t, class ExecutionSpace,
+template <typename input_size_t, typename input_ordinal_t, typename input_scalar_t, class ExecutionSpace,
           class TemporaryMemorySpace, class PersistentMemorySpace>
 class TwoStageGaussSeidelHandle
-    : public GaussSeidelHandle<input_size_t, input_ordinal_t, input_scalar_t,
-                               ExecutionSpace, TemporaryMemorySpace,
+    : public GaussSeidelHandle<input_size_t, input_ordinal_t, input_scalar_t, ExecutionSpace, TemporaryMemorySpace,
                                PersistentMemorySpace> {
  public:
   using memory_space = typename ExecutionSpace::memory_space;
@@ -647,9 +513,8 @@ class TwoStageGaussSeidelHandle
   using size_type    = typename std::remove_const<input_size_t>::type;
 
   using device_t = Kokkos::Device<ExecutionSpace, TemporaryMemorySpace>;
-  using crsmat_t =
-      KokkosSparse::CrsMatrix<scalar_t, ordinal_t, device_t, void, size_type>;
-  using graph_t = typename crsmat_t::StaticCrsGraphType;
+  using crsmat_t = KokkosSparse::CrsMatrix<scalar_t, ordinal_t, device_t, void, size_type>;
+  using graph_t  = typename crsmat_t::StaticCrsGraphType;
 
   using input_row_map_view_t = typename graph_t::row_map_type;
   using input_entries_view_t = typename graph_t::entries_type;
@@ -667,12 +532,10 @@ class TwoStageGaussSeidelHandle
   using const_ordinal_t = typename const_entries_view_t::value_type;
   using const_scalar_t  = typename const_values_view_t::value_type;
 
-  using vector_view_t = Kokkos::View<scalar_t **, default_layout, device_t>;
+  using vector_view_t = Kokkos::View<scalar_t **, KokkosKernels::default_layout, device_t>;
 
-  using GSHandle =
-      GaussSeidelHandle<input_size_t, input_ordinal_t, input_scalar_t,
-                        ExecutionSpace, TemporaryMemorySpace,
-                        PersistentMemorySpace>;
+  using GSHandle = GaussSeidelHandle<input_size_t, input_ordinal_t, input_scalar_t, ExecutionSpace,
+                                     TemporaryMemorySpace, PersistentMemorySpace>;
 
   using HandleExecSpace = typename GSHandle::HandleExecSpace;
 
@@ -698,8 +561,7 @@ class TwoStageGaussSeidelHandle
    * @brief Construct a new Two Stage Gauss Seidel Handle object
    *
    */
-  TwoStageGaussSeidelHandle()
-      : TwoStageGaussSeidelHandle(GSHandle(GS_TWOSTAGE)) {}
+  TwoStageGaussSeidelHandle() : TwoStageGaussSeidelHandle(GSHandle(GS_TWOSTAGE)) {}
 
   /**
    * @brief Construct a new Two Stage Gauss Seidel Handle object
@@ -708,13 +570,10 @@ class TwoStageGaussSeidelHandle
    * @param n_streams the number of streams
    */
   TwoStageGaussSeidelHandle(HandleExecSpace handle_exec_space, int n_streams)
-      : TwoStageGaussSeidelHandle(
-            GSHandle(handle_exec_space, n_streams, GS_TWOSTAGE)) {}
+      : TwoStageGaussSeidelHandle(GSHandle(handle_exec_space, n_streams, GS_TWOSTAGE)) {}
 
   // Sweep direction
-  void setSweepDirection(GSDirection direction_) {
-    this->direction = direction_;
-  }
+  void setSweepDirection(GSDirection direction_) { this->direction = direction_; }
   GSDirection getSweepDirection() { return this->direction; }
 
   // specify whether to perform inner sweeps
@@ -722,27 +581,19 @@ class TwoStageGaussSeidelHandle
   bool isTwoStage() { return this->two_stage; }
 
   // specify whether to use compact form of recurrence
-  void setCompactForm(bool compact_form_) {
-    this->compact_form = compact_form_;
-  }
+  void setCompactForm(bool compact_form_) { this->compact_form = compact_form_; }
   bool isCompactForm() { return this->compact_form; }
 
   // Number of outer sweeps
-  void setNumOuterSweeps(int num_outer_sweeps_) {
-    this->num_outer_sweeps = num_outer_sweeps_;
-  }
+  void setNumOuterSweeps(int num_outer_sweeps_) { this->num_outer_sweeps = num_outer_sweeps_; }
   int getNumOuterSweeps() { return this->num_outer_sweeps; }
 
   // Number of inner sweeps
-  void setNumInnerSweeps(int num_inner_sweeps_) {
-    this->num_inner_sweeps = num_inner_sweeps_;
-  }
+  void setNumInnerSweeps(int num_inner_sweeps_) { this->num_inner_sweeps = num_inner_sweeps_; }
   int getNumInnerSweeps() { return this->num_inner_sweeps; }
 
   // Inner damping factor
-  void setInnerDampFactor(scalar_t inner_omega_) {
-    this->inner_omega = inner_omega_;
-  }
+  void setInnerDampFactor(scalar_t inner_omega_) { this->inner_omega = inner_omega_; }
   scalar_t getInnerDampFactor() { return this->inner_omega; }
 
   // Workspaces
