@@ -7,6 +7,7 @@
 // *****************************************************************************
 // @HEADER
 
+#include <cstddef>
 #include <cstdio>
 #include <iomanip>
 #include <iostream>
@@ -35,6 +36,7 @@
 #include <MueLu.hpp>
 
 #include <MueLu_BaseClass.hpp>
+#include "Xpetra_Access.hpp"
 #ifdef HAVE_MUELU_EXPLICIT_INSTANTIATION
 #include <MueLu_ExplicitInstantiation.hpp>
 #endif
@@ -104,7 +106,7 @@ void equilibrateMatrix(Teuchos::RCP<Xpetra::Matrix<Scalar, LocalOrdinal, GlobalO
   bool assumeSymmetric   = false;
   typedef typename Tpetra::Details::EquilibrationInfo<typename Kokkos::ArithTraits<Scalar>::val_type, typename Node::device_type> equil_type;
 
-  Teuchos::RCP<Tpetra::CrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > A = Utilities::Op2NonConstTpetraCrs(Axpetra);
+  Teuchos::RCP<Tpetra::CrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node> > A = toTpetra(Axpetra);
 
   if (Axpetra->getRowMap()->lib() == Xpetra::UseTpetra) {
     equil_type equibResult_ = computeRowAndColumnOneNorms(*A, assumeSymmetric);
@@ -199,9 +201,13 @@ int main_(Teuchos::CommandLineProcessor& clp, Xpetra::UnderlyingLib& lib, int ar
   int writeMatricesOPT = -2;
   clp.setOption("write", &writeMatricesOPT, "write matrices to file (-1 means all; i>=0 means level i)");
   std::string dsolveType = "belos", solveType;
-  clp.setOption("solver", &dsolveType, "solve type: (none | belos | standalone | matvec)");
+  clp.setOption("solver", &dsolveType, "solve type: (none | belos | standalone | matvec | simple_cg )");
   std::string belosType = "cg";
   clp.setOption("belosType", &belosType, "belos solver type: (Pseudoblock CG | Block CG | Pseudoblock GMRES | Block GMRES | ...) see BelosSolverFactory.hpp for exhaustive list of solvers");
+  bool computeCondEst = false;
+  clp.setOption("condEst", "noCondEst", &computeCondEst, "compute condition number estimate (currently only available for Pseudoblock CG)");
+  bool enforceBoundaryConditionsOnInitialGuess = true;
+  clp.setOption("enforceBCs", "noEnforceBCs", &enforceBoundaryConditionsOnInitialGuess, "enforce Dirichlet boundary condition on initial guess");
   double dtol = 1e-12, tol;
   clp.setOption("tol", &dtol, "solver convergence tolerance");
   bool binaryFormat = false;
@@ -229,6 +235,8 @@ int main_(Teuchos::CommandLineProcessor& clp, Xpetra::UnderlyingLib& lib, int ar
   clp.setOption("nullspace", &nullFile, "nullspace data file");
   std::string materialFile;
   clp.setOption("material", &materialFile, "material data file");
+  bool tensorMaterialCoefficient = true;
+  clp.setOption("tensorCoefficient", "scalarCoefficient", &tensorMaterialCoefficient, "Generate a tensor or scalar material coefficient if none is passed in from file");
   bool setNullSpace = true;
   clp.setOption("driver-nullspace", "muelu-computed-nullspace", &setNullSpace, "driver sets nullspace");
   int numRebuilds = 0;
@@ -377,8 +385,10 @@ int main_(Teuchos::CommandLineProcessor& clp, Xpetra::UnderlyingLib& lib, int ar
   RCP<Matrix> A;
   RCP<const Map> map;
   RCP<RealValuedMultiVector> coordinates;
-  RCP<Xpetra::MultiVector<SC, LO, GO, NO> > nullspace, material;
-  RCP<MultiVector> X, B;
+  RCP<Xpetra::MultiVector<SC, LO, GO, NO> > nullspace;
+  RCP<Xpetra::MultiVector<SC, LO, GO, NO> > material;
+  RCP<MultiVector> X;
+  RCP<MultiVector> B;
 
   // Load the matrix off disk (or generate it via Galeri)
   MatrixLoad<SC, LO, GO, NO>(comm, lib, binaryFormat, matrixFile, rhsFile, rowMapFile, colMapFile, domainMapFile, rangeMapFile, coordFile, coordMapFile, nullFile, materialFile, map, A, coordinates, nullspace, material, X, B, numVectors, galeriParameters, xpetraParameters, galeriStream);
@@ -434,6 +444,25 @@ int main_(Teuchos::CommandLineProcessor& clp, Xpetra::UnderlyingLib& lib, int ar
       }
     }
 
+    if (material.is_null() && !coordinates.is_null()) {
+      size_t dim = coordinates->getNumVectors();
+      if (tensorMaterialCoefficient) {
+        material = MultiVectorFactory::Build(map, dim * dim);
+        int k    = 0;
+        for (size_t i = 0; i < dim; ++i)
+          for (size_t j = 0; j < dim; ++j) {
+            if (i == j)
+              material->getVectorNonConst(k)->putScalar(2.0 * Teuchos::ScalarTraits<SC>::one());
+            else
+              material->getVectorNonConst(k)->putScalar(Teuchos::ScalarTraits<SC>::zero());
+            ++k;
+          }
+      } else {
+        material = MultiVectorFactory::Build(map, 1);
+        material->putScalar(2.0 * Teuchos::ScalarTraits<SC>::one());
+      }
+    }
+
     // If doing user based block smoothing, read block information from file.
     // Must do this for both smoothers and coarse solvers
 
@@ -490,16 +519,17 @@ int main_(Teuchos::CommandLineProcessor& clp, Xpetra::UnderlyingLib& lib, int ar
         userParamList.set("Node Comm", nodeComm);
       }
 #endif
-      out2 << "*********** MueLu ParameterList ***********" << std::endl;
-      out2 << mueluList;
-      out2 << "*******************************************" << std::endl;
-
       RCP<Hierarchy> H;
       RCP<Operator> Prec;
       // Build the preconditioner numRebuilds+1 times
-      MUELU_SWITCH_TIME_MONITOR(tm, "Driver: 2 - MueLu Setup");
-      PreconditionerSetup(A, coordinates, nullspace, material, mueluList, profileSetup, useAMGX, useML, setNullSpace, numRebuilds, H, Prec);
+      if (solvePreconditioned) {
+        out2 << "*********** MueLu ParameterList ***********" << std::endl;
+        out2 << mueluList;
+        out2 << "*******************************************" << std::endl;
 
+        MUELU_SWITCH_TIME_MONITOR(tm, "Driver: 2 - MueLu Setup");
+        PreconditionerSetup(A, coordinates, nullspace, material, mueluList, profileSetup, useAMGX, useML, setNullSpace, numRebuilds, H, Prec);
+      }
       comm->barrier();
       tm = Teuchos::null;
 
@@ -521,7 +551,7 @@ int main_(Teuchos::CommandLineProcessor& clp, Xpetra::UnderlyingLib& lib, int ar
         }
 
         // Solve the system numResolves+1 times
-        SystemSolve(A, X, B, H, Prec, out2, solveType, belosType, profileSolve, useAMGX, useML, cacheSize, numResolves, scaleResidualHist, solvePreconditioned, maxIts, tol);
+        SystemSolve(A, X, B, H, Prec, out2, solveType, belosType, profileSolve, useAMGX, useML, cacheSize, numResolves, scaleResidualHist, solvePreconditioned, maxIts, tol, computeCondEst, enforceBoundaryConditionsOnInitialGuess);
 
         comm->barrier();
       } catch (const std::exception& e) {
