@@ -69,7 +69,6 @@ TEST(StkMeshIoBrokerHowTo, interpolateFieldNegativeTime)
     //+ The value of the field at each node is 0.0 at time 0.0,
     //+ -1.0 at time -1.0, and -2.0 at time -2.0
     stk::io::StkMeshIoBroker stkIo(communicator);
-    stkIo.use_simple_fields();
 
     const std::string generatedFileName = "generated:8x8x8|nodeset:xyz";
     stkIo.add_mesh_database(generatedFileName, stk::io::READ_MESH);
@@ -108,7 +107,6 @@ TEST(StkMeshIoBrokerHowTo, interpolateFieldNegativeTime)
     //+ of 0.1 (-2.0, -1.9, -1.8, ..., 0.0) and verify that
     //+ the field contains the correct interpolated value.
     stk::io::StkMeshIoBroker stkIo(communicator);
-    stkIo.use_simple_fields();
     stkIo.add_mesh_database(ic_name, stk::io::READ_MESH);
     stkIo.create_input_mesh();
 
@@ -132,7 +130,7 @@ TEST(StkMeshIoBrokerHowTo, interpolateFieldNegativeTime)
       //+ VERIFICATION
       // The value of the "temperature" field at all nodes should be 'time'
       stk::mesh::for_each_entity_run(stkIo.bulk_data(), stk::topology::NODE_RANK,
-        [&](const stk::mesh::BulkData& bulk, stk::mesh::Entity node) {
+        [&](const stk::mesh::BulkData& /*bulk*/, stk::mesh::Entity node) {
           double *fieldData = stk::mesh::field_data(temperature, node);
           EXPECT_DOUBLE_EQ(time, *fieldData);
         });
